BuiltInIcons

Struct BuiltInIcons 

pub struct BuiltInIcons {
    pub browse: fn() -> IconWidget,
    pub expand: fn() -> IconWidget,
    pub search: fn() -> IconWidget,
    pub copy: fn() -> IconWidget,
    pub clear: fn() -> IconWidget,
    pub add: fn() -> IconWidget,
    pub bell: fn() -> IconWidget,
    pub eye: fn() -> IconWidget,
    pub eye_off: fn() -> IconWidget,
    pub menu: fn() -> IconWidget,
    pub more: fn() -> IconWidget,
}
Icon factory set for predefined built-in buttons.

Each field is a function pointer that creates an IconWidget. The default implementation uses SVG icons embedded in teksilo-widgets.

Overriding

Call BuiltInIcons::set_global at app startup (before creating any built-in buttons) to replace the default icon set:

BuiltInIcons::set_global(BuiltInIcons {
    browse: || IconWidget::from_svg(MY_BROWSE_SVG),
    clear: || IconWidget::from_svg(MY_CLEAR_SVG),
    ..BuiltInIcons::defaults()
});

Fields

browse: fn() -> IconWidgetexpand: fn() -> IconWidgetsearch: fn() -> IconWidgetcopy: fn() -> IconWidgetclear: fn() -> IconWidgetadd: fn() -> IconWidgetbell: fn() -> IconWidgeteye: fn() -> IconWidgeteye_off: fn() -> IconWidgetmenu: fn() -> IconWidgetmore: fn() -> IconWidget

Implementations

Source

impl BuiltInIcons

pub fn defaults() -> Self

Return the default icon set (SVGs embedded in teksilo-widgets).

pub fn set_global(icons: Self)

Set the global icon set. Call at app startup before creating any built-in buttons. Can only be set once: the global is a process-wide OnceLock, so the first set wins and any later call is ignored (and warns). It is also locked in the first time global() reads it, so set it before any built-in button is created. Use defaults() with struct update syntax to override only specific icons.