pub struct MenuItemRecipe {
pub item_height: f32,
pub padding_horizontal: f32,
pub padding_leading: f32,
pub icon_column_width: f32,
pub icon_label_gap: f32,
pub shortcut_left_gap: f32,
pub separator_height: f32,
pub item_corner_radius: f32,
}Expand description
Recipe dimensions for RecipeMenuItemStyle.
All fields default to the corresponding module-level pub const.
Override individual fields to tune the menu row without writing a full
custom MenuItemStyle impl.
Fields
item_height: f32padding_horizontal: f32padding_leading: f32icon_column_width: f32icon_label_gap: f32shortcut_left_gap: f32separator_height: f32item_corner_radius: f32Trait Implementations
Sourceimpl Clone for MenuItemRecipe
impl Clone for MenuItemRecipe
Sourcefn clone(&self) -> MenuItemRecipe
fn clone(&self) -> MenuItemRecipe
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MenuItemRecipe
Sourceimpl Debug for MenuItemRecipe
impl Debug for MenuItemRecipe
Sourceimpl Default for MenuItemRecipe
impl Default for MenuItemRecipe
Sourceimpl PartialEq for MenuItemRecipe
impl PartialEq for MenuItemRecipe
Sourcefn eq(&self, other: &MenuItemRecipe) -> bool
fn eq(&self, other: &MenuItemRecipe) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MenuItemRecipe